@@ -119,7 +119,6 @@ has directory => (
         clear_live_objects
         
         backend
-        resolver
         linker
         collapser
 
@@ -217,11 +216,17 @@ sub no_live_objects {
     local $Test::Builder::Level = $Test::Builder::Level + 1;
 
     unless ( is( scalar(()=$self->live_objects), 0, "no live objects" ) ){
-        diag "live objects: " . join ", ", map { $self->object_to_id($_) . " ($_)" } $self->live_objects;
-        diag Data::Dumper::Dumper($self->live_objects);
+        my @l = $self->live_objects;
+        diag "live objects: " . join ", ", map { $self->object_to_id($_) . " ($_)" } @l;
+        diag Data::Dumper::Dumper(@l);
+
+        #use Scalar::Util qw(weaken);
+        #weaken($_) for @l;
+
+        #$self->directory->live_objects->clear;
 
         #use Devel::FindRef;
-        #my $track = Devel::FindRef::track($self->live_objects);
+        #my $track = Devel::FindRef::track(@l);
         #warn $track;
         #my ( @ids ) = map { hex } ( $track =~ /by \w+\(0x([a-z0-9]+)\)/ );
         #warn Data::Dumper::Dumper(map { Devel::FindRef::ptr2ref($_) } @ids);
