@@ -47,6 +47,8 @@ sub verify {
         is( $updated_entry->prev, $entry, "parent of updated is orig" );
 
         is( $joe->name, "HALLO", "name attr" );
+
+        undef $joe;
     }
 
     $self->no_live_objects;
@@ -80,18 +82,25 @@ sub verify {
             is( $updated_entry, $entry, "entry rolled back" );
 
             is( $joe->name, "YASE", "name not rolled back in live object" );
+
+            undef $joe;
         }
 
+        $self->no_live_objects;
+
         {
             my $s = $self->new_scope;
 
             my $joe = $self->lookup_ok( $self->joe );
             
             is( $joe->name, "HALLO", "name rolled back in DB" );
-        }
-    }
 
-    $self->no_live_objects;
+            undef $joe;
+        }
+
+        $self->no_live_objects;
+
+    }
 
     {
         {
@@ -128,18 +137,24 @@ sub verify {
             is( $updated_entry, $entry, "entry rolled back" );
 
             is( $joe->name, "oi", "name attr of object" );
+
+            undef $joe;
         }
 
+        $self->no_live_objects;
+
         {
             my $s = $self->new_scope;
 
             my $joe = $self->lookup_ok( $self->joe );
 
             is( $joe->name, "HALLO", "name rolled back in DB" );
-        }
-    }
 
-    $self->no_live_objects;
+            undef $joe;
+        }
+
+        $self->no_live_objects;
+    }
 }
 
 __PACKAGE__->meta->make_immutable;
